==> react-echarts-core-5.2.2.tgz: package/es/EChartsCore.js <==
function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { var _i = arr == null ? null : typeof Symbol !== "undefined" && arr[Symbol.iterator] || arr["@@iterator"]; if (_i == null) return; var _arr = []; var _n = true; var _d = false; var _s, _e; try { for (_i = _i.call(arr); !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) { symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); } keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React from 'react';
import EChartsContext from './context';
import useSize from './hooks/useSize';
var EChartsCore = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var echarts = props.echarts,
      className = props.className,
      style = props.style,
      option = props.option,
      theme = props.theme,
      initOpts = props.initOpts,
      setOptionOpts = props.setOptionOpts,
      autoResize = props.autoResize,
      loading = props.loading,
      loadingConfig = props.loadingConfig,
      group = props.group,
      onChartInit = props.onChartInit,
      onEvents = props.onEvents;
  var echartsContainerRef = React.useRef(null);
  var echartsInstanceRef = React.useRef(null);

  var _React$useContext = React.useContext(EChartsContext),
      contextTheme = _React$useContext.theme,
      contextAutoResize = _React$useContext.autoResize;

  var _useSize = useSize(echartsContainerRef.current || document.body),
      width = _useSize.width,
      height = _useSize.height;

  React.useImperativeHandle(ref, function () {
    return {
      get echartsInstance() {
        return echartsInstanceRef.current;
      }

    };
  });
  /**
   * 创建ECharts实例
   */

  var initECharts = function initECharts() {
    if (echartsContainerRef.current) {
      var offsetHeight = echartsContainerRef.current.offsetHeight;

      var newInitOpts = _objectSpread(_objectSpread({}, initOpts), {}, {
        height: (initOpts === null || initOpts === void 0 ? void 0 : initOpts.height) || offsetHeight || 400
      });

      echartsInstanceRef.current = echarts.init(echartsContainerRef.current, theme || contextTheme, newInitOpts);

      if (onChartInit) {
        onChartInit(echartsInstanceRef.current);
      }

      buildEvents();
      setOption();
    }
  };
  /**
   * 销毁ECharts实例
   */


  var disposeECharts = function disposeECharts() {
    if (echartsInstanceRef.current) {
      echartsInstanceRef.current.dispose();
      echartsInstanceRef.current = null;
    }
  };
  /**
   * 绑定事件
   */


  var buildEvents = function buildEvents() {
    Object.entries(onEvents || {}).forEach(function (_ref) {
      var _ref2 = _slicedToArray(_ref, 2),
          eventName = _ref2[0],
          handler = _ref2[1];

      if (echartsInstanceRef.current) {
        echartsInstanceRef.current.on(eventName, handler);
      }
    });
  };
  /**
   * 设置图表配置项
   */


  var setOption = function setOption() {
    if (echartsInstanceRef.current && option) {
      echartsInstanceRef.current.setOption(option, setOptionOpts);
    }
  };
  /**
   * 调整大小
   */


  var resize = function resize() {
    if ((autoResize || contextAutoResize) && echartsInstanceRef.current) {
      echartsInstanceRef.current.resize();
    }
  };
  /**
   * 切换Loading
   */


  var toggleLoading = function toggleLoading() {
    if (echartsInstanceRef.current) {
      if (loading) {
        echartsInstanceRef.current.showLoading(loadingConfig === null || loadingConfig === void 0 ? void 0 : loadingConfig.type, loadingConfig === null || loadingConfig === void 0 ? void 0 : loadingConfig.opts);
      } else {
        echartsInstanceRef.current.hideLoading();
      }
    }
  };
  /**
   * 设置图表分组
   */


  var setGroup = function setGroup() {
    if (echartsInstanceRef.current && group) {
      echartsInstanceRef.current.group = group;
    }
  };

  React.useEffect(function () {
    initECharts();
    return function () {
      disposeECharts();
    };
  }, [echartsContainerRef, theme, contextTheme, initOpts]);
  React.useEffect(function () {
    setOption();
  }, [option]);
  React.useLayoutEffect(function () {
    resize();
  }, [width, height]);
  React.useEffect(function () {
    toggleLoading();
  }, [loading]);
  React.useEffect(function () {
    setGroup();
  }, [group]);
  return /*#__PURE__*/React.createElement("div", {
    ref: echartsContainerRef,
    className: className,
    style: style
  });
});
EChartsCore.defaultProps = {
  autoResize: false,
  loading: false
};
export default EChartsCore;

==> react-echarts-core-5.2.3.tgz: package/es/EChartsCore.js <==
function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { var _i = arr == null ? null : typeof Symbol !== "undefined" && arr[Symbol.iterator] || arr["@@iterator"]; if (_i == null) return; var _arr = []; var _n = true; var _d = false; var _s, _e; try { for (_i = _i.call(arr); !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) { symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); } keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import classNames from 'classnames';
import React from 'react';
import EChartsContext from './context';
import useSize from './hooks/useSize';
var EChartsCore = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var echarts = props.echarts,
      className = props.className,
      style = props.style,
      option = props.option,
      theme = props.theme,
      initOpts = props.initOpts,
      setOptionOpts = props.setOptionOpts,
      autoResize = props.autoResize,
      loading = props.loading,
      loadingConfig = props.loadingConfig,
      group = props.group,
      onChartInit = props.onChartInit,
      onEvents = props.onEvents;
  var echartsContainerRef = React.useRef(null);
  var echartsInstanceRef = React.useRef(null);

  var _React$useContext = React.useContext(EChartsContext),
      contextTheme = _React$useContext.theme,
      contextAutoResize = _React$useContext.autoResize;

  var _useSize = useSize(echartsContainerRef.current || document.body),
      width = _useSize.width,
      height = _useSize.height;

  React.useImperativeHandle(ref, function () {
    return {
      get echartsInstance() {
        return echartsInstanceRef.current;
      }

    };
  });
  /**
   * 创建ECharts实例
   */

  var initECharts = function initECharts() {
    if (echartsContainerRef.current) {
      var offsetHeight = echartsContainerRef.current.offsetHeight;

      var newInitOpts = _objectSpread(_objectSpread({}, initOpts), {}, {
        height: (initOpts === null || initOpts === void 0 ? void 0 : initOpts.height) || offsetHeight || 400
      });

      echartsInstanceRef.current = echarts.init(echartsContainerRef.current, theme || contextTheme, newInitOpts);

      if (onChartInit) {
        onChartInit(echartsInstanceRef.current);
      }

      buildEvents();
      setOption();
    }
  };
  /**
   * 销毁ECharts实例
   */


  var disposeECharts = function disposeECharts() {
    if (echartsInstanceRef.current) {
      echartsInstanceRef.current.dispose();
      echartsInstanceRef.current = null;
    }
  };
  /**
   * 绑定事件
   */


  var buildEvents = function buildEvents() {
    Object.entries(onEvents || {}).forEach(function (_ref) {
      var _ref2 = _slicedToArray(_ref, 2),
          eventName = _ref2[0],
          handler = _ref2[1];

      if (echartsInstanceRef.current) {
        echartsInstanceRef.current.on(eventName, handler);
      }
    });
  };
  /**
   * 设置图表配置项
   */


  var setOption = function setOption() {
    if (echartsInstanceRef.current && option) {
      echartsInstanceRef.current.setOption(option, setOptionOpts);
    }
  };
  /**
   * 调整大小
   */


  var resize = function resize() {
    if ((autoResize || contextAutoResize) && echartsInstanceRef.current) {
      echartsInstanceRef.current.resize();
    }
  };
  /**
   * 切换Loading
   */


  var toggleLoading = function toggleLoading() {
    if (echartsInstanceRef.current) {
      if (loading) {
        echartsInstanceRef.current.showLoading(loadingConfig === null || loadingConfig === void 0 ? void 0 : loadingConfig.type, loadingConfig === null || loadingConfig === void 0 ? void 0 : loadingConfig.opts);
      } else {
        echartsInstanceRef.current.hideLoading();
      }
    }
  };
  /**
   * 设置图表分组
   */


  var setGroup = function setGroup() {
    if (echartsInstanceRef.current && group) {
      echartsInstanceRef.current.group = group;
    }
  };

  React.useEffect(function () {
    initECharts();
    return function () {
      disposeECharts();
    };
  }, [echartsContainerRef, theme, contextTheme, initOpts]);
  React.useEffect(function () {
    setOption();
  }, [option]);
  React.useLayoutEffect(function () {
    resize();
  }, [width, height]);
  React.useEffect(function () {
    toggleLoading();
  }, [loading]);
  React.useEffect(function () {
    setGroup();
  }, [group]);
  return /*#__PURE__*/React.createElement("div", {
    ref: echartsContainerRef,
    className: classNames('react-echarts', className),
    style: style
  });
});
EChartsCore.defaultProps = {
  autoResize: false,
  loading: false
};
export default EChartsCore;
